clc
clear
close all

%load data from files
CPIall=load('Data\CPI_SA.txt'); % cpi data
load Data\CPI_wts.txt; % cpi weights
Labels=textread('Data\Labels.txt','%s'); % labels for countries
CPI_lbs=textread('Data\CPI_lbs.txt','%s'); %cpi labels
Labels=char(Labels);
CPI_lbs=char(CPI_lbs);
Quarters=textread('Data\Quarters.txt','%s');
Quarters=char(Quarters);

%extensive country labels (order as in Labels.txt)
country  = {'Belgium';'Canada';'Switzerland';'France';...
            'Germany';'Italy';'Japan';'Netherlands';'US'};  

%set size parameters
atemp=size(Quarters);
btemp=size(Labels);
time=atemp(1);
count=btemp(1);

%compute median component weights across countries 
%and normalize to 1
Cwts=median(CPI_wts,2)/sum(median(CPI_wts,2));

%read component series from CPIall data file
CPI_AI   =CPIall(:,1:5:45);
CPI_AGLF =CPIall(:,2:5:45);
CPI_FOOD =CPIall(:,3:5:45);
CPI_HAU  =CPIall(:,4:5:45);
CPI_SLH  =CPIall(:,5:5:45);

%construct from component series
%   - cpiT (tradeable CPI), weighted using median country weights
%   - cpiN (nontradable CPI), weighted using median country weights
%   - and cpiA (all items), country specific weights

for t=1:time
    for i=1:count  
        cpiT(t,i)=(Cwts(1)/sum(Cwts(1:2)))*CPI_AGLF(t,i)+(Cwts(2)/sum(Cwts(1:2)))*CPI_FOOD(t,i);
        cpiN(t,i)=(Cwts(3)/sum(Cwts(3:4)))*CPI_HAU(t,i)+(Cwts(4)/sum(Cwts(3:4)))*CPI_SLH(t,i);
        CPI_AI(t,i)=Cwts(1)*CPI_AGLF(t,i)+Cwts(2)*CPI_FOOD(t,i)+Cwts(3)*CPI_HAU(t,i)+Cwts(4)*CPI_SLH(t,i);
end
end

%detrend series (HP 1600)
dcpiT=log(cpiT)-hptrend(log(cpiT),1600);
dcpiN=log(cpiN)-hptrend(log(cpiN),1600);
dcpiA=log(CPI_AI)-hptrend(log(CPI_AI),1600);

%dump output files (used in RER.m)
fid = fopen('Data\CPI_T.txt','w');
fprintf(fid,'%6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f\n',cpiT');
fclose(fid);
fid = fopen('Data\CPI_N.txt','w');
fprintf(fid,'%6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f\n',cpiN');
fclose(fid);
fid = fopen('Data\CPI_A.txt','w');
fprintf(fid,'%6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f\n',CPI_AI');
fclose(fid);

%compute summary statistics
for i=1:count
SDA(i)=std(dcpiA(:,i))*100;
SDN(i)=std(dcpiN(:,i))*100;
SDT(i)=std(dcpiT(:,i))*100;
CCNT(:,:,i)=corrcoef(dcpiN(:,i),dcpiT(:,i));
CCT(:,:,i) =corrcoef(dcpiT(:,i),dcpiA(:,i));
CCN(:,:,i) =corrcoef(dcpiN(:,i),dcpiA(:,i));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Print summary statistics to
%Table 2 and display
file ={'Table2.txt'};
title={'Tradable and non-tradable CPI components$^{a}$'};
label={'Table2'};
chead=[0 1 2 2 1 2 2;
       1 1 1 1 1 1 1];
hrow={'Correlation','Standard deviation (\%)',...
        'Country','\small $P^{T},P^{N}$','\small $P^{T},P$',...
        '\small $P^{N},P$','\small $P^{T}$','\small $P^{N}$','\small $P$'}
data=ones(count,6);
for i=1:count
    data(i,:)=[CCNT(2,1,i) CCT(2,1,i) CCN(2,1,i) SDT(i) SDN(i) SDA(i)];
end
fcol=country; 
csin=[1.2;0.6;0.6;0.6;0.5;0.5;0.5];
dec =[      2;  2;  2;  1;  1;  1];
opt=[1 0]; hline=[]; small=[];
fnote={'$^{a}P^{T}$ denotes index of tradable component of $CPI$ (all goods less food + food), $P^{N}$ denotes index of non-tradable components of $CPI$ (services less housing + housing), $P$ denotes all items CPI (weighted average of all components). All series constructed using fixed sample median weights of underlying components. Statistics based on logged and Hodrick-Prescott filtered quarterly series for the period 1980:1-2000:1. Sources listed in the Appendix.'};

TabTeX(file,title,label,chead,hrow,fcol,hline,csin,dec,data,fnote,opt,small);


